@@ -1,13 +1,14 @@
 /* Miscellaneous functions module for the Lua/APR binding.
  *
  * Author: Peter Odding <peter@peterodding.com>
- * Last Change: March 28, 2011
+ * Last Change: June 23, 2011
  * Homepage: http://peterodding.com/code/lua/apr/
  * License: MIT
  */
 
 #include "lua_apr.h"
 #include <apr_portable.h>
+#include <ctype.h>
 
 /* Used to make sure that APR is only initialized once. */
 static int apr_was_initialized = 0;
@@ -152,6 +153,13 @@ LUA_APR_EXPORT int luaopen_apr_core(lua_State *L)
     { "shm_attach", lua_apr_shm_attach },
     { "shm_remove", lua_apr_shm_remove },
 
+    /* signal.c -- signal handling. */
+    { "signal", lua_apr_signal },
+    { "signal_raise", lua_apr_signal_raise },
+    { "signal_block", lua_apr_signal_block },
+    { "signal_unblock", lua_apr_signal_unblock },
+    { "signal_names", lua_apr_signal_names },
+
     /* str.c -- string handling. */
     { "strnatcmp", lua_apr_strnatcmp },
     { "strnatcasecmp", lua_apr_strnatcasecmp },
@@ -209,10 +217,6 @@ LUA_APR_EXPORT int luaopen_apr_core(lua_State *L)
     if (atexit(apr_terminate) != 0)
       raise_error_message(L, "Lua/APR: Failed to register apr_terminate()");
     apr_was_initialized = 1;
-#   if APR_HAS_THREADS
-    /* Initialize the thread module's mutex and condition variables. */
-    threads_initialize(L);
-#   endif
   }
 
   /* Create the `scratch' memory pool for global APR functions (as opposed to
@@ -371,9 +375,14 @@ int lua_apr_type(lua_State *L)
 
 int status_to_message(lua_State *L, apr_status_t status)
 {
+  int length;
   char message[LUA_APR_MSGSIZE];
+
   apr_strerror(status, message, count(message));
-  lua_pushstring(L, message);
+  length = strlen(message);
+  while (length > 0 && isspace(message[length - 1]))
+    length--;
+  lua_pushlstring(L, message, length);
   return 1;
 }
 
