@@ -1,7 +1,7 @@
 /* Header file for the Lua/APR binding.
  *
  * Author: Peter Odding <peter@peterodding.com>
- * Last Change: March 27, 2011
+ * Last Change: June 23, 2011
  * Homepage: http://peterodding.com/code/lua/apr/
  * License: MIT
  */
@@ -338,10 +338,10 @@ apr_pool_t *to_pool(lua_State*);
 
 /* object.c */
 void *new_object(lua_State*, lua_apr_objtype*);
-void *prepare_reference(lua_State*, lua_apr_objtype*, lua_apr_refobj*);
+void *prepare_reference(lua_apr_objtype*, lua_apr_refobj*);
 void init_object(lua_State*, lua_apr_objtype*);
 int object_collectable(lua_apr_refobj*);
-void release_object(lua_State*, lua_apr_refobj*);
+void release_object(lua_apr_refobj*);
 void object_env_default(lua_State*);
 int object_env_private(lua_State*, int);
 int object_has_type(lua_State*, int, lua_apr_objtype*, int);
@@ -373,6 +373,13 @@ int lua_apr_shm_create(lua_State*);
 int lua_apr_shm_attach(lua_State*);
 int lua_apr_shm_remove(lua_State*);
 
+/* signal.c */
+int lua_apr_signal(lua_State*);
+int lua_apr_signal_raise(lua_State*);
+int lua_apr_signal_block(lua_State*);
+int lua_apr_signal_unblock(lua_State*);
+int lua_apr_signal_names(lua_State*);
+
 /* str.c */
 int lua_apr_strnatcmp(lua_State*);
 int lua_apr_strnatcasecmp(lua_State*);
@@ -382,10 +389,6 @@ int lua_apr_tokenize_to_argv(lua_State*);
 /* thread.c */
 int lua_apr_thread_create(lua_State*);
 int lua_apr_thread_yield(lua_State*);
-void threads_initialize(lua_State*);
-void threads_increment(lua_State*);
-void threads_decrement(lua_State*);
-void threads_terminate();
 
 /* thread_queue.c */
 int lua_apr_thread_queue(lua_State*);
